//                              -*- Mode: C++ -*- 
// 
// uC++ Version 5.3.0, Copyright (C) Peter A. Buhr 1994
// 
// uBootTask.h -- 
// 
// Author           : Peter Buhr
// Created On       : Thu Apr 28 11:54:04 1994
// Last Modified By : Peter A. Buhr
// Last Modified On : Mon Jun 13 14:29:17 2005
// Update Count     : 26
//
// This  library is free  software; you  can redistribute  it and/or  modify it
// under the terms of the GNU Lesser General Public License as published by the
// Free Software  Foundation; either  version 2.1 of  the License, or  (at your
// option) any later version.
// 
// This library is distributed in the  hope that it will be useful, but WITHOUT
// ANY  WARRANTY;  without even  the  implied  warranty  of MERCHANTABILITY  or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
// for more details.
// 
// You should  have received a  copy of the  GNU Lesser General  Public License
// along  with this library.
// 


#ifndef __U_BOOTTASK_H__
#define __U_BOOTTASK_H__


_Task uBootTask {
    friend class uKernelBoot;				// access: new

    void main();

    void *operator new( size_t, void *storage );
    void *operator new( size_t size );
  public:
    uBootTask();
    ~uBootTask();
}; // uBootTask


#endif // __U_BOOTTASK_H__


// Local Variables: //
// compile-command: "gmake install" //
// End: //
